@@ -1,6 +1,6 @@
 (* Otags reloaded
  * 
- * Hendrik Tews Copyright (C) 2010 - 2012
+ * Hendrik Tews Copyright (C) 2010 - 2016
  * 
  * This file is part of "Otags reloaded".
  * 
@@ -19,7 +19,7 @@
  * along with "Otags reloaded". If not, see
  * <http://www.gnu.org/licenses/>.
  * 
- * $Id: monitor_line_directive.ml,v 1.1 2012/02/17 13:06:25 tews Exp $
+ * $Id: monitor_line_directive.ml,v 1.3 2016/01/14 20:17:46 tews Exp $
  * 
  * filter and store line directives
  * 
@@ -34,6 +34,9 @@ type line_directive_record = {
 
 let parsed_line_directives = ref []
 
+let last_filename = ref None
+
+
 let parse_line_directive file line parse_offset =
   parsed_line_directives := 
     { ld_file = file;
@@ -57,7 +60,9 @@ struct
   let monitor_line_directive token loc = match token with
     | Sig.LINE_DIRECTIVE(line, file_opt) ->
       (* 
-       * Printf.eprintf "LD [%s: sl %d(%d) so %d el %d(%d) eo %d%s] : %d %s\n%!"
+       * Printf.eprintf
+       * 	("LD [%s: sl %d(%d) so %d el %d(%d) eo %d%s] : %d %s "
+       * 	 ^^ "(last file %s)\n%!")
        * 	(Loc.file_name loc)
        * 	(Loc.start_line loc) (Loc.start_bol loc) (Loc.start_off loc)
        * 	(Loc.stop_line loc) (Loc.stop_bol loc) (Loc.stop_off loc)
@@ -66,12 +71,23 @@ struct
        * 	(match file_opt with
        * 	  | Some f -> f
        * 	  | None -> "<no file>"
+       * 	)
+       * 	(match !last_filename with
+       * 	   | None -> "<no last filename>"
+       * 	   | Some f -> f
        * 	);
        *)
-      (match file_opt with
-	| None -> assert false
-	| Some file -> parse_line_directive file line (Loc.stop_off loc)
-      )
+      let file = match file_opt with
+	  | None -> 
+	     (match !last_filename with
+		| Some file -> file
+		| None -> assert false
+	     )
+	  | Some file ->
+	     last_filename := Some file;
+	     file
+      in
+      parse_line_directive file line (Loc.stop_off loc)
 
     | Sig.KEYWORD       _
     | Sig.SYMBOL        _
