@@ -1,6 +1,6 @@
 (* Otags reloaded
  * 
- * Hendrik Tews Copyright (C) 2010 - 2012
+ * Hendrik Tews Copyright (C) 2010 - 2016
  * 
  * This file is part of "Otags reloaded".
  * 
@@ -19,23 +19,36 @@
  * along with "Otags reloaded". If not, see
  * <http://www.gnu.org/licenses/>.
  * 
- * $Id: monitor_line_directive.mli,v 1.1 2012/02/17 13:06:25 tews Exp $
+ * $Id: monitor_line_directive.mli,v 1.3 2016/01/14 20:17:46 tews Exp $
  * 
  * filter and store line directives
  * 
  *)
 
+
+(** Record for storing line directives for correcting character
+    offsets in locations.
+ *)
 type line_directive_record = {
-  ld_file : string;
-  ld_line : int;
-  ld_parse_offset : int;
-  mutable ld_file_offset : int;
+  ld_file : string;	    (** the file name of the line directive *)
+  ld_line : int;	    (** the line number of the line directive *)
+  ld_parse_offset : int;    (** the character offset of the end of the line
+                                directive in the parsed character stream *)
+  mutable ld_file_offset : int;	(** cache for the character offset of line 
+                                ld_line in file ld_file, -1 when invalid, 
+                                written in Tranlate_location when needed. *)
 }
 
+(** list of all line directives after parsing completed. Should be reset
+    after each parsed unit.
+ *)
 val parsed_line_directives : line_directive_record list ref
 
-
-val parse_line_directive : string -> int -> int -> unit
+(** Last filename seen in a line directive for cppo, which emits 
+    line directives without filenames. Not used outside of this module, 
+    but should be reset together with parsed_line_directives.
+ *)
+val last_filename : string option ref
 
 module Line_directive_monitor : 
   functor(Syn : Camlp4.Sig.Camlp4Syntax) -> Camlp4.Sig.Camlp4Syntax
