@@ -195,6 +195,20 @@ let rec a88_eval : type a. a a87_term -> a = function
   | App(f,x) -> (a88_eval f) (a88_eval x)
 
 
+type a89 = ..
+
+type a89 += A90 of int * string
+
+type a89 += A91
+
+let a90 [@foo "bar"] = 5
+
+let (a91, a92 [@foo 55]) = (3,4)
+
+let (a93 [@foo 55], a94) = (3,4)
+
+let (  or ) l1 l2 = l1 @ l2
+
 (*** Local Variables: ***)
 (*** compile-command: "make -C .. testtrue" ***)
 (*** End: ***)
